/*
	**
	** report.c
	**
	** Routines and data structures used to store and manage packet 
	** summary report
	**
	** Copyright 1998-1999 Damien Miller <dmiller@ilogic.com.au>
	**
	** This software is licensed under the terms of the GNU General 
	** Public License (GPL). Please see the file COPYING for details.
	** 
	** $Id: report.c,v 1.2 1999/02/04 10:22:42 dmiller Exp $
	**
 */

#include <stdlib.h>
#include "report.h"

static char rcsid[] = "$Id: report.c,v 1.2 1999/02/04 10:22:42 dmiller Exp $";

void free_report(report_t *r)
{
	free_hosts(r->hosts);
	free(r);
}

void free_host(host_t *h)
{
	if (h->hostname != NULL)
		free(h->hostname);
	free(h);
}

void free_hosts(host_t *h)
{
	host_t *last_h;

	while (h != NULL)
	{
		last_h = h;
		h = h->next;

		free_peers(last_h->peers);
		free_host(last_h);
	}
}

void free_peer(peer_t *p)
{
	free(p);
}

void free_peers(peer_t *p)
{
	peer_t *last_p;

	while (p != NULL)
	{
		last_p = p;
		p = p->next;

		free_peer(last_p);
	}
}

/* Hashes a host's ip address */
unsigned int host_hash(u_int32_t *ip_addr)
{
	return((unsigned int)(*ip_addr));
}

/* Compares two hosts */
unsigned int host_compare(u_int32_t *ip_addr1, u_int32_t *ip_addr2)
{
	return((*ip_addr1) == (*ip_addr2));
}
