/*
	**
	** util.h
	**
	** Miscellaneous utility routines
	**
	** Copyright 1998-1999 Damien Miller <dmiller@ilogic.com.au>
	**
	** This software is licensed under the terms of the GNU General 
	** Public License (GPL). Please see the file COPYING for details.
	** 
	** $Id: util.c,v 1.4 1999/02/04 10:22:42 dmiller Exp $
	**
 */

#include <stdlib.h>
#include <unistd.h>
#include <stdio.h>
#include <string.h>
#include <signal.h>
#include <time.h>
#include <sys/types.h>
#include <math.h>

#include <glib.h>

#include "util.h"

static char rcsid[] = "$Id: util.c,v 1.4 1999/02/04 10:22:42 dmiller Exp $";

/* Allocates s bytes, checking for allocation errors */
void *util_malloc(size_t s)
{
	void *m;
	
	m = g_malloc(s);

	if (m == NULL)
	{
		fprintf(stderr, "\nOut of memory.\n");
		raise(SIGSEGV);
	}
	
	return(m);
}

/* Allocates s zero-filled bytes, checking for allocation errors */
void *util_zmalloc(size_t s)
{
	void *m;
	
	m = g_malloc(s);

	if (m == NULL)
	{
		fprintf(stderr, "\nOut of memory.\n");
		raise(SIGSEGV);
	}
	
	memset(m, 0, s);
	
	return(m);
}

/* Duplicates string s, checking for allocation errors */
void *util_strdup(const char *s)
{
	char *m;
	
	m = g_strdup(s);

	if (m == NULL)
	{
		fprintf(stderr, "\nOut of memory.\n");
		raise(SIGSEGV);
	}
	
	return(m);
}

/* Resizes allocation m to s bytes, checking for allocation errors */
void *util_realloc(void *m, size_t s)
{
	m = g_realloc(m, s);

	if (m == NULL)
	{
		fprintf(stderr, "\nOut of memory.\n");
		raise(SIGSEGV);
	}
	
	return(m);
}

/* Seeds RNG  */
void util_seed_rng(void)
{
	srandom(time(NULL) ^ (getpid() + (getppid() << 15)));
}

